#!/usr/bin/env python

"""Tests for PPS-related functionality."""

import time

import pytest
import grpc

import python_pachyderm
from tests import util


class Sandbox:
    def __init__(self, test_name):
        client = python_pachyderm.Client()
        client.delete_all()
        commit, input_repo_name, pipeline_repo_name = util.create_test_pipeline(
            client, test_name
        )
        self.client = client
        self.commit = commit
        self.input_repo_name = input_repo_name
        self.pipeline_repo_name = pipeline_repo_name

    def wait_for_job(self):
        return util.wait_for_job(self.client, self.commit)


def test_list_job():
    sandbox = Sandbox("list_job")
    job_id = sandbox.wait_for_job()

    jobs = list(sandbox.client.list_job())
    assert len(jobs) >= 1

    jobs = list(sandbox.client.list_job(pipeline_name=sandbox.pipeline_repo_name))
    assert len(jobs) >= 1

    jobs = list(
        sandbox.client.list_job(
            input_commit=(sandbox.input_repo_name, sandbox.commit.id)
        )
    )
    assert len(jobs) >= 1


def test_flush_job():
    sandbox = Sandbox("flush_job")
    jobs = list(sandbox.client.flush_job([sandbox.commit]))
    assert len(jobs) >= 1
    print(jobs[0])


def test_inspect_job():
    sandbox = Sandbox("inspect_job")
    job_id = sandbox.wait_for_job()

    job = sandbox.client.inspect_job(job_id)
    assert job.job.id == job_id


def test_stop_job():
    sandbox = Sandbox("stop_job")
    job_id = sandbox.wait_for_job()

    sandbox.client.stop_job(job_id)
    # This is necessary because `StopJob` does not wait for the job to be killed before returning a result.
    # TODO: remove once this is fixed:
    # https://github.com/pachyderm/pachyderm/issues/3856
    time.sleep(1)
    job = sandbox.client.inspect_job(job_id)
    # We race to stop the job before it finishes - if we lose the race, it will be in state JOB_SUCCESS
    assert (
        job.state == python_pachyderm.JobState.JOB_KILLED.value
        or job.state == python_pachyderm.JobState.JOB_SUCCESS.value
    )


def test_delete_job():
    sandbox = Sandbox("delete_job")
    job_id = sandbox.wait_for_job()
    orig_job_count = len(list(sandbox.client.list_job()))
    sandbox.client.delete_job(job_id)
    assert len(list(sandbox.client.list_job())) == orig_job_count - 1


def test_datums():
    sandbox = Sandbox("datums")
    job_id = sandbox.wait_for_job()

    # flush the job so it fully finishes
    list(sandbox.client.flush_commit([(sandbox.input_repo_name, sandbox.commit.id)]))

    datums = list(sandbox.client.list_datum(job_id))
    assert len(datums) == 1
    datum = sandbox.client.inspect_datum(job_id, datums[0].datum_info.datum.id)
    assert datum.state == python_pachyderm.DatumState.SUCCESS.value

    # Skip this check in >=1.11.0, due to a bug:
    # https://github.com/pachyderm/pachyderm/issues/5123
    # TODO: remove this check once the bug is fixed
    if util.test_pachyderm_version() < (1, 11, 0):
        # Just ensure this doesn't raise an exception
        sandbox.client.restart_datum(job_id)


def test_inspect_pipeline():
    sandbox = Sandbox("inspect_pipeline")
    pipeline = sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name)
    assert pipeline.pipeline.name == sandbox.pipeline_repo_name
    if util.test_pachyderm_version() >= (1, 9, 0):
        pipeline = sandbox.client.inspect_pipeline(
            sandbox.pipeline_repo_name, history=-1
        )
        assert pipeline.pipeline.name == sandbox.pipeline_repo_name


def test_list_pipeline():
    sandbox = Sandbox("list_pipeline")
    pipelines = sandbox.client.list_pipeline()
    assert sandbox.pipeline_repo_name in [
        p.pipeline.name for p in pipelines.pipeline_info
    ]
    pipelines = sandbox.client.list_pipeline(history=-1)
    assert sandbox.pipeline_repo_name in [
        p.pipeline.name for p in pipelines.pipeline_info
    ]


def test_delete_pipeline():
    sandbox = Sandbox("delete_pipeline")
    orig_pipeline_count = len(sandbox.client.list_pipeline().pipeline_info)
    sandbox.client.delete_pipeline(sandbox.pipeline_repo_name)
    assert len(sandbox.client.list_pipeline().pipeline_info) == orig_pipeline_count - 1


def test_delete_all_pipelines():
    sandbox = Sandbox("delete_all_pipelines")
    sandbox.client.delete_all_pipelines()
    pipelines = sandbox.client.list_pipeline()
    assert len(pipelines.pipeline_info) == 0


def test_restart_pipeline():
    sandbox = Sandbox("restart_job")

    sandbox.client.stop_pipeline(sandbox.pipeline_repo_name)
    pipeline = sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name)
    assert pipeline.stopped

    sandbox.client.start_pipeline(sandbox.pipeline_repo_name)
    pipeline = sandbox.client.inspect_pipeline(sandbox.pipeline_repo_name)
    assert not pipeline.stopped


@util.skip_if_below_pachyderm_version(1, 9, 0)
def test_run_pipeline():
    sandbox = Sandbox("run_pipeline")

    # flush the job so it fully finishes
    list(sandbox.client.flush_commit([(sandbox.input_repo_name, sandbox.commit.id)]))

    # just make sure it worked
    sandbox.client.run_pipeline(sandbox.pipeline_repo_name)


@util.skip_if_below_pachyderm_version(1, 9, 10)
def test_run_cron():
    sandbox = Sandbox("run_cron")

    # flush the job so it fully finishes
    list(sandbox.client.flush_commit([(sandbox.input_repo_name, sandbox.commit.id)]))

    # this should trigger an error because the sandbox pipeline doesn't have a
    # cron input
    # NOTE: `e` is used after the context
    with pytest.raises(python_pachyderm.RpcError) as e:
        sandbox.client.run_cron(sandbox.pipeline_repo_name)
    assert "pipeline must have a cron input" in str(e.value)


@util.skip_if_below_pachyderm_version(1, 10, 0)
def test_secrets():
    client = python_pachyderm.Client()
    secret_name = util.test_repo_name("test-secrets")

    client.create_secret(
        secret_name,
        {
            "mykey": "my-value",
        },
    )

    secret = client.inspect_secret(secret_name)
    assert secret.secret.name == secret_name

    secrets = client.list_secret()
    assert len(secrets) == 1
    assert secrets[0].secret.name == secret_name

    client.delete_secret(secret_name)

    with pytest.raises(python_pachyderm.RpcError):
        client.inspect_secret(secret_name)

    secrets = client.list_secret()
    assert len(secrets) == 0


def test_get_pipeline_logs():
    sandbox = Sandbox("get_pipeline_logs")
    job_id = sandbox.wait_for_job()

    # Wait for the job to complete
    list(sandbox.client.flush_job([sandbox.commit]))

    # Just make sure these spit out some logs
    logs = sandbox.client.get_pipeline_logs(sandbox.pipeline_repo_name)
    assert next(logs) is not None

    logs = sandbox.client.get_pipeline_logs(sandbox.pipeline_repo_name, master=True)
    assert next(logs) is not None


# job logs are available in 1.8.x, but they frequently fail due to bugs that
# are resolved in 1.9.0
@util.skip_if_below_pachyderm_version(1, 9, 0)
def test_get_job_logs():
    sandbox = Sandbox("get_logs_logs")
    job_id = sandbox.wait_for_job()

    # Wait for the job to complete
    list(sandbox.client.flush_job([sandbox.commit]))

    # Just make sure these spit out some logs
    logs = sandbox.client.get_job_logs(job_id)
    assert next(logs) is not None


def test_create_pipeline_from_request():
    client = python_pachyderm.Client()

    repo_name = util.create_test_repo(client, "test_create_pipeline_from_request")
    pipeline_name = util.test_repo_name("test_create_pipeline_from_request")

    # more or less a copy of the opencv demo's edges pipeline spec
    client.create_pipeline_from_request(
        python_pachyderm.CreatePipelineRequest(
            pipeline=python_pachyderm.Pipeline(name=pipeline_name),
            description="A pipeline that performs image edge detection by using the OpenCV library.",
            input=python_pachyderm.Input(
                pfs=python_pachyderm.PFSInput(
                    glob="/*",
                    repo=repo_name,
                ),
            ),
            transform=python_pachyderm.Transform(
                cmd=["echo", "hi"],
                image="pachyderm/opencv",
            ),
        )
    )

    assert any(
        p.pipeline.name == pipeline_name for p in client.list_pipeline().pipeline_info
    )



#!/usr/bin/env python

"""Tests PFS-related functionality"""

import pytest
import tempfile
from io import BytesIO

import python_pachyderm
from tests import util


def sandbox(test_name):
    client = python_pachyderm.Client()
    repo_name = util.create_test_repo(client, test_name)
    return client, repo_name


def test_inspect_repo():
    client, repo_name = sandbox("inspect_repo")
    client.inspect_repo(repo_name)
    repos = client.list_repo()
    assert len(repos) >= 1
    assert repo_name in [r.repo.name for r in repos]


def test_delete_repo():
    client, repo_name = sandbox("delete_repo")
    orig_repo_count = len(client.list_repo())
    assert orig_repo_count >= 1
    client.delete_repo(repo_name)
    assert len(client.list_repo()) == orig_repo_count - 1


def test_delete_non_existent_repo():
    client = python_pachyderm.Client()
    orig_repo_count = len(client.list_repo())
    client.delete_repo("BOGUS_NAME")
    assert len(client.list_repo()) == orig_repo_count


def test_delete_all_repos():
    client = python_pachyderm.Client()

    util.create_test_repo(client, "test_delete_all_repos", prefix="extra-1")
    util.create_test_repo(client, "test_delete_all_repos", prefix="extra-2")
    assert len(client.list_repo()) >= 2

    client.delete_all_repos()
    assert len(client.list_repo()) == 0


def test_start_commit():
    client, repo_name = sandbox("start_commit")

    commit = client.start_commit(repo_name, "master")
    assert commit.repo.name == repo_name

    commit = client.start_commit(repo_name, None)
    assert commit.repo.name == repo_name

    with pytest.raises(python_pachyderm.RpcError):
        client.start_commit("some-fake-repo", "master")


def test_start_commit_with_parent_no_branch():
    client, repo_name = sandbox("start_commit_with_parent_no_branch")

    commit1 = client.start_commit(repo_name)
    client.finish_commit((repo_name, commit1.id))

    commit2 = client.start_commit(repo_name, parent=commit1.id)
    assert commit2.repo.name == repo_name


def test_start_commit_on_branch_with_parent():
    client, repo_name = sandbox("start_commit_on_branch_with_parent")

    commit1 = client.start_commit(repo_name, branch="master")
    client.finish_commit((repo_name, commit1.id))

    commit2 = client.start_commit(repo_name, branch="master", parent=commit1.id)
    assert commit2.repo.name == repo_name


def test_start_commit_fork():
    client, repo_name = sandbox("start_commit_fork")

    commit1 = client.start_commit(repo_name, branch="master")
    client.finish_commit((repo_name, commit1.id))

    commit2 = client.start_commit(repo_name, branch="patch", parent="master")

    assert commit2.repo.name == repo_name

    branches = [branch_info.name for branch_info in client.list_branch(repo_name)]
    assert "master" in branches
    assert "patch" in branches


@pytest.mark.parametrize(
    "commit_arg", ["commit_obj", "repo/commit_id", "(repo, commit_id)"]
)
def test_finish_commit(commit_arg):
    client, repo_name = sandbox("finish_commit")
    commit = client.start_commit(repo_name)

    if commit_arg == "commit_obj":
        client.finish_commit(commit)
    elif commit_arg == "repo/commit_id":
        client.finish_commit("{}/{}".format(repo_name, commit.id))
    elif commit_arg == "(repo, commit_id)":
        client.finish_commit((repo_name, commit.id))

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == commit.id

    commit_match_count = len(
        [
            c
            for c in commit_infos
            if c.commit.id == commit.id and c.finished.seconds != 0
        ]
    )
    assert commit_infos[0].finished.seconds != 0
    assert commit_infos[0].finished.nanos != 0


def test_commit_context_mgr():
    """Start and finish a commit using a context manager."""

    client, repo_name = sandbox("commit_context_mgr")

    with client.commit(repo_name, "master") as c1:
        pass
    with client.commit(repo_name, None) as c2:
        pass

    with pytest.raises(python_pachyderm.RpcError):
        with client.commit("some-fake-repo", "master"):
            pass

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 2
    assert sorted([c.commit.id for c in commit_infos]) == sorted([c1.id, c2.id])


def test_put_file_bytes_bytestring():
    """
    Start and finish a commit using a context manager while putting a file
    from a bytesting.
    """

    client, repo_name = sandbox("put_file_bytes_bytestring")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file.dat", b"DATA")

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    files = list(client.list_file("{}/{}".format(repo_name, c.id), "."))
    assert len(files) == 1


def test_put_file_bytes_bytestring_with_overwrite():
    """
    Start and finish a commit using a context manager while putting a file
    from a bytesting.
    """

    client, repo_name = sandbox("put_file_bytes_bytestring_with_overwrite")

    with client.commit(repo_name, "mybranch") as c:
        for i in range(5):
            client.put_file_bytes(c, "file.dat", b"DATA")

    with client.commit(repo_name, "mybranch") as c:
        client.put_file_bytes(c, "file.dat", b"FOO", overwrite_index=2)

    # read the file as an iterator
    file = list(client.get_file("{}/{}".format(repo_name, c.id), "file.dat"))
    assert file == [b"DATA", b"DATA", b"FOO"]

    # read the file as a file-like object
    file = client.get_file("{}/{}".format(repo_name, c.id), "file.dat")
    assert file.read(1) == b"D"
    assert file.read(0) == b""
    assert file.read(5) == b"ATADA"
    assert file.read() == b"TAFOO"
    assert file.read(0) == b""
    file.close()  # should be a no-op
    assert file.read() == b""

    # read the file as a file-like object, but close before reading everything
    file = client.get_file("{}/{}".format(repo_name, c.id), "file.dat")
    assert file.read(1) == b"D"
    file.close()
    assert file.read() == b""


def test_put_file_bytes_filelike():
    """
    Start and finish a commit using a context manager while putting a file
    from a file-like object.
    """

    client, repo_name = sandbox("put_file_bytes_filelike")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file.dat", BytesIO(b"DATA"))

    files = list(client.list_file("{}/{}".format(repo_name, c.id), "."))
    assert len(files) == 1


def test_put_file_zero_bytes_pfc():
    """
    Put a zero-byte file using PutFileClient
    """

    client, repo_name = sandbox("put_file_bytes_file_zero_byte")

    commit = "{}/master".format(repo_name)
    with client.put_file_client() as c:
        c.put_file_from_bytes(commit, "file.dat", b"")
    files = list(client.list_file(commit, "."))
    assert len(files) == 1
    fi = client.inspect_file(commit, "file.dat")
    assert fi.size_bytes == 0


def test_put_file_bytes_zero_bytes_direct():
    """
    Put a zero-byte file using a bytestring iterator (tests zero-byte behavior
    in put_file_from_iterable_reqs)
    """

    client, repo_name = sandbox("put_file_bytes_zero_bytes")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "empty_iter.dat", [])
    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    fi = client.inspect_file(c, "empty_iter.dat")
    assert fi.size_bytes == 0

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "empty_bytestring.dat", [b""])
    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 2
    assert commit_infos[0].commit.id == c.id
    fi = client.inspect_file(c, "empty_bytestring.dat")
    assert fi.size_bytes == 0


def test_put_file_bytes_iterable():
    """
    Start and finish a commit using a context manager while putting a file
    from an iterator of bytes.
    """

    client, repo_name = sandbox("put_file_bytes_iterable")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file.dat", [b"DATA"])

    files = list(client.list_file("{}/{}".format(repo_name, c.id), "."))
    assert len(files) == 1


def test_put_file_bytes_large():
    """
    Put a file larger than the maximum message size.
    """

    client, repo_name = sandbox("put_file_bytes_large")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file.dat", b"#" * (21 * 1024 * 1024))

    commit_infos = list(client.list_commit(repo_name))
    assert len(commit_infos) == 1
    assert commit_infos[0].commit.id == c.id
    files = list(client.list_file("{}/{}".format(repo_name, c.id), "."))
    assert len(files) == 1


def test_put_file_url():
    client, repo_name = sandbox("put_file_url")

    with client.commit(repo_name) as c:
        client.put_file_url(
            c,
            "index.html",
            "https://gist.githubusercontent.com/ysimonson/1986773831f6c4c292a7290c5a5d4405/raw/fb2b4d03d317816e36697a6864a9c27645baa6c0/wheel.html",
        )

    files = list(client.list_file("{}/{}".format(repo_name, c.id), "."))
    assert len(files) == 1
    assert files[0].file.path == "/index.html"


def test_put_file_atomic():
    client, repo_name = sandbox("put_file_atomic")
    commit = (repo_name, "master")

    with tempfile.NamedTemporaryFile() as f:
        with client.put_file_client() as pfc:
            pfc.put_file_from_fileobj(commit, "file1.dat", BytesIO(b"DATA1"))
            pfc.put_file_from_bytes(commit, "file2.dat", b"DATA1")
            pfc.put_file_from_url(
                commit,
                "index.html",
                "https://gist.githubusercontent.com/ysimonson/1986773831f6c4c292a7290c5a5d4405/raw/fb2b4d03d317816e36697a6864a9c27645baa6c0/wheel.html",
            )

            f.write(b"DATA3")
            f.flush()
            pfc.put_file_from_filepath(commit, "file3.dat", f.name)

    files = list(client.list_file(commit, "."))
    assert len(files) == 4
    assert files[0].file.path == "/file1.dat"
    assert files[1].file.path == "/file2.dat"
    assert files[2].file.path == "/file3.dat"
    assert files[3].file.path == "/index.html"

    # atomic deletes are only supported in 1.11.0 onwards
    if util.test_pachyderm_version() >= (1, 11, 0):
        with client.put_file_client() as pfc:
            pfc.delete_file(commit, "/file1.dat")
            pfc.delete_file(commit, "/file2.dat")
            pfc.delete_file(commit, "/file3.dat")

        files = list(client.list_file(commit, "."))
        assert len(files) == 1
        assert files[0].file.path == "/index.html"


def test_copy_file():
    client, repo_name = sandbox("copy_file")

    with client.commit(repo_name, "master") as src_commit:
        client.put_file_bytes(src_commit, "file1.dat", BytesIO(b"DATA1"))
        client.put_file_bytes(src_commit, "file2.dat", BytesIO(b"DATA2"))

    with client.commit(repo_name, "master") as dest_commit:
        client.copy_file(src_commit, "file1.dat", dest_commit, "copy.dat")
        client.copy_file(
            src_commit, "file2.dat", dest_commit, "copy.dat", overwrite=True
        )

    files = list(client.list_file("{}/{}".format(repo_name, dest_commit.id), "."))
    assert len(files) == 3
    assert files[0].file.path == "/copy.dat"
    assert files[1].file.path == "/file1.dat"
    assert files[2].file.path == "/file2.dat"


def test_flush_commit():
    """
    Ensure flush commit works
    """

    client, repo_name = sandbox("flush_commit")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "input.json", b"hello world")

    # Just block until all of the commits are yielded
    list(client.flush_commit(["{}/{}".format(repo_name, c.id)]))

    files = list(client.list_file("{}/master".format(repo_name), "/"))
    assert len(files) == 1


def test_inspect_commit():
    client, repo_name = sandbox("inspect_commit")

    with client.commit(repo_name, "master") as c:
        client.put_file_bytes(c, "input.json", b"hello world")

    commit = client.inspect_commit("{}/master".format(repo_name))
    if util.test_pachyderm_version() >= (1, 9, 0):
        assert commit.branch.name == "master"
    assert commit.finished
    assert commit.description == ""
    assert commit.size_bytes == 11
    assert len(commit.commit.id) == 32
    assert commit.commit.repo.name == repo_name


def test_delete_commit():
    client, repo_name = sandbox("delete_commit")

    with client.commit(repo_name, "master") as c:
        pass

    commits = list(client.list_commit(repo_name))
    assert len(commits) == 1
    client.delete_commit("{}/master".format(repo_name))
    commits = list(client.list_commit(repo_name))
    assert len(commits) == 0


def test_subscribe_commit():
    client, repo_name = sandbox("subscribe_commit")
    commits = client.subscribe_commit(repo_name, "master")

    with client.commit(repo_name, "master") as c:
        pass

    commit = next(commits)
    if util.test_pachyderm_version() >= (1, 9, 0):
        assert commit.branch.repo.name == repo_name
        assert commit.branch.name == "master"


def test_list_branch():
    client, repo_name = sandbox("list_branch")

    with client.commit(repo_name, "master") as c:
        pass
    with client.commit(repo_name, "develop") as c:
        pass

    branches = client.list_branch(repo_name)
    assert len(branches) == 2
    assert branches[0].name == "develop"
    assert branches[1].name == "master"


def test_delete_branch():
    client, repo_name = sandbox("delete_branch")

    with client.commit(repo_name, "develop") as c:
        pass

    branches = client.list_branch(repo_name)
    assert len(branches) == 1
    client.delete_branch(repo_name, "develop")
    branches = client.list_branch(repo_name)
    assert len(branches) == 0


def test_inspect_file():
    client, repo_name = sandbox("inspect_file")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file.dat", [b"DATA"])

    fi = client.inspect_file(c, "file.dat")
    assert fi.file.commit.id == c.id
    assert fi.file.commit.repo.name == repo_name
    assert fi.file.path == "file.dat"
    assert fi.size_bytes == 4
    assert (
        fi.objects[0].hash
        == "4ba7d4149c32f5ccc6e54190beef0f503d1e637249baa9e4b123f5aa5c89506f299c10a7e32ab1e4bae30ed32df848f87d9b03a640320b0ca758c5ee56cb2db4"
    )


def test_list_file():
    client, repo_name = sandbox("list_file")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file1.dat", [b"DATA"])
        client.put_file_bytes(c, "file2.dat", [b"DATA"])

    files = list(client.list_file(c, "/"))
    assert len(files) == 2
    assert files[0].size_bytes == 4
    assert files[0].file_type == python_pachyderm.FileType.FILE.value
    assert files[0].file.path == "/file1.dat"
    assert files[1].size_bytes == 4
    assert files[1].file_type == python_pachyderm.FileType.FILE.value
    assert files[1].file.path == "/file2.dat"


def test_walk_file():
    client, repo_name = sandbox("walk_file")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "/file1.dat", [b"DATA"])
        client.put_file_bytes(c, "/a/file2.dat", [b"DATA"])
        client.put_file_bytes(c, "/a/b/file3.dat", [b"DATA"])

    files = list(client.walk_file(c, "/a"))
    assert len(files) == 4
    assert files[0].file.path == "/a"
    assert files[1].file.path == "/a/b"
    assert files[2].file.path == "/a/b/file3.dat"
    assert files[3].file.path == "/a/file2.dat"


def test_glob_file():
    client, repo_name = sandbox("glob_file")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file1.dat", [b"DATA"])
        client.put_file_bytes(c, "file2.dat", [b"DATA"])

    files = list(client.glob_file(c, "/*.dat"))
    assert len(files) == 2
    assert files[0].size_bytes == 4
    assert files[0].file_type == python_pachyderm.FileType.FILE.value
    assert files[0].file.path == "/file1.dat"
    assert files[1].size_bytes == 4
    assert files[1].file_type == python_pachyderm.FileType.FILE.value
    assert files[1].file.path == "/file2.dat"

    files = list(client.glob_file(c, "/*1.dat"))
    assert len(files) == 1
    assert files[0].size_bytes == 4
    assert files[0].file_type == python_pachyderm.FileType.FILE.value
    assert files[0].file.path == "/file1.dat"


def test_delete_file():
    client, repo_name = sandbox("delete_file")

    with client.commit(repo_name) as c:
        client.put_file_bytes(c, "file1.dat", [b"DATA"])

    assert len(list(client.list_file(c, "/"))) == 1

    with client.commit(repo_name) as c:
        client.delete_file(c, "file1.dat")

    assert len(list(client.list_file(c, "/"))) == 0


def test_create_branch():
    client, repo_name = sandbox("create_branch")
    client.create_branch(repo_name, "foobar")
    branches = client.list_branch(repo_name)
    assert len(branches) == 1
    assert branches[0].name == "foobar"


def test_inspect_branch():
    client, repo_name = sandbox("inspect_branch")
    client.create_branch(repo_name, "foobar")
    branch = client.inspect_branch(repo_name, "foobar")
    assert branch.branch.name == "foobar"


@util.skip_if_below_pachyderm_version(1, 9, 7)
def test_fsck():
    client = python_pachyderm.Client()
    assert len(list(client.fsck())) == 0


def test_diff_file():
    client, repo_name = sandbox("diff_file")

    with client.commit(repo_name, "master") as old_commit:
        client.put_file_bytes(old_commit, "file1.dat", BytesIO(b"old data 1"))
        client.put_file_bytes(old_commit, "file2.dat", BytesIO(b"old data 2"))

    with client.commit(repo_name, "master") as new_commit:
        client.put_file_bytes(new_commit, "file1.dat", BytesIO(b"new data 1"))

    diff = client.diff_file(new_commit, "file1.dat", old_commit, "file2.dat")
    assert diff.new_files[0].file.path == "file1.dat"
    assert diff.old_files[0].file.path == "file2.dat"

    diff = client.diff_file(new_commit, "file1.dat")
    assert diff.new_files[0].file.path == "file1.dat"
    assert diff.old_files[0].file.path == "file1.dat"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from python_pachyderm.proto.debug import debug_pb2 as client_dot_debug_dot_debug__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


class DebugStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Profile = channel.unary_stream(
        '/debug.Debug/Profile',
        request_serializer=client_dot_debug_dot_debug__pb2.ProfileRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.Binary = channel.unary_stream(
        '/debug.Debug/Binary',
        request_serializer=client_dot_debug_dot_debug__pb2.BinaryRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.Dump = channel.unary_stream(
        '/debug.Debug/Dump',
        request_serializer=client_dot_debug_dot_debug__pb2.DumpRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )


class DebugServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Profile(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Binary(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Dump(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DebugServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Profile': grpc.unary_stream_rpc_method_handler(
          servicer.Profile,
          request_deserializer=client_dot_debug_dot_debug__pb2.ProfileRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'Binary': grpc.unary_stream_rpc_method_handler(
          servicer.Binary,
          request_deserializer=client_dot_debug_dot_debug__pb2.BinaryRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'Dump': grpc.unary_stream_rpc_method_handler(
          servicer.Dump,
          request_deserializer=client_dot_debug_dot_debug__pb2.DumpRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'debug.Debug', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import os
import json
from pathlib import Path
from urllib.parse import urlparse

from .mixin.admin import AdminMixin
from .mixin.auth import AuthMixin
from .mixin.debug import DebugMixin
from .mixin.enterprise import EnterpriseMixin
from .mixin.health import HealthMixin
from .mixin.pfs import PFSMixin
from .mixin.pps import PPSMixin
from .mixin.transaction import TransactionMixin
from .mixin.version import VersionMixin


class ConfigError(Exception):
    """Error for issues related to the pachyderm config file"""

    def __init__(self, message):
        super().__init__(message)


class BadClusterDeploymentID(ConfigError):
    """
    Error triggered when connected to a cluster that reports back a different
    cluster deployment ID than what is stored in the config file
    """

    def __init__(self, expected_deployment_id, actual_deployment_id):
        super().__init__(
            "connected to the wrong cluster ('{}' vs '{}')".format(
                expected_deployment_id, actual_deployment_id
            )
        )
        self.expected_deployment_id = expected_deployment_id
        self.actual_deployment_id = actual_deployment_id


class Client(
    AdminMixin,
    AuthMixin,
    DebugMixin,
    EnterpriseMixin,
    HealthMixin,
    PFSMixin,
    PPSMixin,
    TransactionMixin,
    VersionMixin,
    object,
):
    def __init__(
        self,
        host=None,
        port=None,
        auth_token=None,
        root_certs=None,
        transaction_id=None,
        tls=None,
    ):
        """
        Creates a Pachyderm client.

        Params:

        * `host`: The pachd host. Default is 'localhost', which is used with
        `pachctl port-forward`.
        * `port`: The port to connect to. Default is 30650.
        * `auth_token`: The authentication token; used if authentication is
        enabled on the cluster. Defaults to `None`.
        * `root_certs`:  The PEM-encoded root certificates as byte string.
        * `transaction_id`: The ID of the transaction to run operations on.
        * `tls`: Specifies whether TLS should be used. If `root_certs` are
        specified, they are used; otherwise, we use the certs provided by
        certifi.
        """

        host = host or "localhost"
        port = port or 30650

        if auth_token is None:
            auth_token = os.environ.get("PACH_PYTHON_AUTH_TOKEN")

        if tls is None:
            tls = root_certs is not None
        if tls and root_certs is None:
            # load default certs if none are specified
            import certifi

            with open(certifi.where(), "rb") as f:
                root_certs = f.read()

        self.address = "{}:{}".format(host, port)
        self.root_certs = root_certs
        self._stubs = {}
        self._auth_token = auth_token
        self._transaction_id = transaction_id
        self._metadata = self._build_metadata()
        if not auth_token and os.environ.get("PACH_PYTHON_OIDC_TOKEN"):
            resp = self.authenticate_id_token(os.environ.get("PACH_PYTHON_OIDC_TOKEN"))
            self._auth_token = resp
            self._metadata = self._build_metadata()

    @classmethod
    def new_in_cluster(cls, auth_token=None, transaction_id=None):
        """
        Creates a Pachyderm client that operates within a Pachyderm cluster.

        Params:

        * `auth_token`: The authentication token; used if authentication is
        enabled on the cluster. Default to `None`.
        * `transaction_id`: The ID of the transaction to run operations on.
        """

        if (
            "PACHD_PEER_SERVICE_HOST" in os.environ
            and "PACHD_PEER_SERVICE_PORT" in os.environ
        ):
            # Try to use the pachd peer service if it's available. This is
            # only supported in pachyderm>=1.10, but is more reliable because
            # it'll work when TLS is enabled on the cluster.
            host = os.environ["PACHD_PEER_SERVICE_HOST"]
            port = int(os.environ["PACHD_PEER_SERVICE_PORT"])
        else:
            # Otherwise use the normal service host/port, which will not work
            # when TLS is enabled on the cluster.
            host = os.environ["PACHD_SERVICE_HOST"]
            port = int(os.environ["PACHD_SERVICE_PORT"])

        return cls(
            host=host, port=port, auth_token=auth_token, transaction_id=transaction_id
        )

    @classmethod
    def new_from_pachd_address(
        cls, pachd_address, auth_token=None, root_certs=None, transaction_id=None
    ):
        """
        Creates a Pachyderm client from a given pachd address.

        Params:

        * `auth_token`: The authentication token; used if authentication is
        enabled on the cluster. Default to `None`.
        * `root_certs`: The PEM-encoded root certificates as byte string. If
        unspecified, this will load default certs from certifi.
        * `transaction_id`: The ID of the transaction to run operations on.
        """

        if "://" not in pachd_address:
            pachd_address = "grpc://{}".format(pachd_address)

        u = urlparse(pachd_address)

        if u.scheme not in ("grpc", "http", "grpcs", "https"):
            raise ValueError("unrecognized pachd address scheme: {}".format(u.scheme))
        if u.path != "" or u.params != "" or u.query != "" or u.fragment != "":
            raise ValueError("invalid pachd address")
        if u.username is not None or u.password is not None:
            raise ValueError("invalid pachd address")

        return cls(
            host=u.hostname,
            port=u.port,
            auth_token=auth_token,
            root_certs=root_certs,
            transaction_id=transaction_id,
            tls=u.scheme == "grpcs" or u.scheme == "https",
        )

    @classmethod
    def new_from_config(cls, config_file=None):
        """
        Creates a Pachyderm client from a config file, which can either be
        passed in as a file-like object, or if unset, checks the PACH_CONFIG env
        var for a path. If that's also unset, it defaults to loading from
        '~/.pachyderm/config.json'.

        Params:

        * `config_file`: An optional file-like object containing the config
        json file. If unspecified, we load the config from the default
        location ('~/.pachyderm/config.json'.)
        """

        if config_file is not None:
            j = json.load(config_file)
        elif "PACH_CONFIG" in os.environ:
            with open(os.environ.get("PACH_CONFIG"), "r") as config_file:
                j = json.load(config_file)
                print("config: {}".format(str(j)))
        else:
            try:
                # Search for config file in default home location
                with open(
                    str(Path.home() / ".pachyderm/config.json"), "r"
                ) as config_file:
                    j = json.load(config_file)
            except FileNotFoundError:
                # If not found, search in "/pachctl" (default mount for spout)
                with open("/pachctl/config.json", "r") as config_file:
                    j = json.load(config_file)

        try:
            active_context = j["v2"]["active_context"]
        except KeyError:
            raise ConfigError("no active context")

        try:
            context = j["v2"]["contexts"][active_context]
        except KeyError:
            raise ConfigError("missing active context '{}'".format(active_context))

        auth_token = context.get("session_token")
        root_certs = context.get("server_cas")
        transaction_id = context.get("active_transaction")

        pachd_address = context.get("pachd_address")
        if pachd_address:
            client = cls.new_from_pachd_address(
                pachd_address,
                auth_token=auth_token,
                root_certs=root_certs,
                transaction_id=transaction_id,
            )
        else:
            port_forwarders = context.get("port_forwarders", {})
            pachd_port = port_forwarders.get("pachd", 30650)
            pachd_address = "grpc://localhost:{}".format(pachd_port)
            client = cls.new_from_pachd_address(
                pachd_address, auth_token=auth_token, transaction_id=transaction_id
            )

        expected_deployment_id = context.get("cluster_deployment_id")
        if expected_deployment_id:
            cluster_info = client.inspect_cluster()
            if cluster_info.deployment_id != expected_deployment_id:
                raise BadClusterDeploymentID(
                    expected_deployment_id, cluster_info.deployment_id
                )

        return client

    @property
    def auth_token(self):
        return self._auth_token

    @auth_token.setter
    def auth_token(self, value):
        self._auth_token = value
        self._metadata = self._build_metadata()

    @property
    def transaction_id(self):
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, value):
        self._transaction_id = value
        self._metadata = self._build_metadata()

    def _build_metadata(self):
        metadata = []
        if self._auth_token is not None:
            metadata.append(("authn-token", self._auth_token))
        if self._transaction_id is not None:
            metadata.append(("pach-transaction", self._transaction_id))
        return metadata

    def _req(self, grpc_service, grpc_method_name, req=None, **kwargs):
        stub = self._stubs.get(grpc_service)
        if stub is None:
            grpc_module = grpc_service.grpc_module
            if self.root_certs:
                ssl_channel_credentials = grpc_module.grpc.ssl_channel_credentials
                ssl = ssl_channel_credentials(root_certificates=self.root_certs)
                channel = grpc_module.grpc.secure_channel(self.address, ssl)
            else:
                channel = grpc_module.grpc.insecure_channel(self.address)
            stub = grpc_service.stub(channel)
            self._stubs[grpc_service] = stub

        assert req is None or len(kwargs) == 0
        assert self._metadata is not None

        if req is None:
            proto_module = grpc_service.proto_module
            if grpc_method_name.endswith("Stream"):
                req_cls_name_prefix = grpc_method_name[:-6]
            else:
                req_cls_name_prefix = grpc_method_name
            req_cls = getattr(proto_module, "{}Request".format(req_cls_name_prefix))
            req = req_cls(**kwargs)

        grpc_method = getattr(stub, grpc_method_name)
        return grpc_method(req, metadata=self._metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/admin.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from python_pachyderm.proto.admin.v1_7.pfs import pfs_pb2 as client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_7.pps import pps_pb2 as client_dot_admin_dot_v1__7_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_8.pfs import pfs_pb2 as client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_8.pps import pps_pb2 as client_dot_admin_dot_v1__8_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_9.pfs import pfs_pb2 as client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_9.pps import pps_pb2 as client_dot_admin_dot_v1__9_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_10.pfs import pfs_pb2 as client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_10.pps import pps_pb2 as client_dot_admin_dot_v1__10_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_11.pfs import pfs_pb2 as client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_11.pps import pps_pb2 as client_dot_admin_dot_v1__11_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_11.auth import auth_pb2 as client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2
from python_pachyderm.proto.admin.v1_11.enterprise import enterprise_pb2 as client_dot_admin_dot_v1__11_dot_enterprise_dot_enterprise__pb2
from python_pachyderm.proto.admin.v1_12.pfs import pfs_pb2 as client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.admin.v1_12.pps import pps_pb2 as client_dot_admin_dot_v1__12_dot_pps_dot_pps__pb2
from python_pachyderm.proto.admin.v1_12.auth import auth_pb2 as client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2
from python_pachyderm.proto.admin.v1_12.enterprise import enterprise_pb2 as client_dot_admin_dot_v1__12_dot_enterprise_dot_enterprise__pb2
from python_pachyderm.proto.pfs import pfs_pb2 as client_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.pps import pps_pb2 as client_dot_pps_dot_pps__pb2
from python_pachyderm.proto.auth import auth_pb2 as client_dot_auth_dot_auth__pb2
from python_pachyderm.proto.enterprise import enterprise_pb2 as client_dot_enterprise_dot_enterprise__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/admin.proto',
  package='admin',
  syntax='proto3',
  serialized_options=b'Z/github.com/pachyderm/pachyderm/src/client/admin',
  serialized_pb=b'\n\x18\x63lient/admin/admin.proto\x12\x05\x61\x64min\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1f\x63lient/admin/v1_7/pfs/pfs.proto\x1a\x1f\x63lient/admin/v1_7/pps/pps.proto\x1a\x1f\x63lient/admin/v1_8/pfs/pfs.proto\x1a\x1f\x63lient/admin/v1_8/pps/pps.proto\x1a\x1f\x63lient/admin/v1_9/pfs/pfs.proto\x1a\x1f\x63lient/admin/v1_9/pps/pps.proto\x1a client/admin/v1_10/pfs/pfs.proto\x1a client/admin/v1_10/pps/pps.proto\x1a client/admin/v1_11/pfs/pfs.proto\x1a client/admin/v1_11/pps/pps.proto\x1a\"client/admin/v1_11/auth/auth.proto\x1a.client/admin/v1_11/enterprise/enterprise.proto\x1a client/admin/v1_12/pfs/pfs.proto\x1a client/admin/v1_12/pps/pps.proto\x1a\"client/admin/v1_12/auth/auth.proto\x1a.client/admin/v1_12/enterprise/enterprise.proto\x1a\x14\x63lient/pfs/pfs.proto\x1a\x14\x63lient/pps/pps.proto\x1a\x16\x63lient/auth/auth.proto\x1a\"client/enterprise/enterprise.proto\"\x10\n\x0e\x43heckAuthToken\"\x91\x02\n\x05Op1_7\x12)\n\x06object\x18\x02 \x01(\x0b\x32\x19.pfs_1_7.PutObjectRequest\x12&\n\x03tag\x18\x03 \x01(\x0b\x32\x19.pfs_1_7.TagObjectRequest\x12(\n\x04repo\x18\x04 \x01(\x0b\x32\x1a.pfs_1_7.CreateRepoRequest\x12+\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1b.pfs_1_7.BuildCommitRequest\x12,\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1c.pfs_1_7.CreateBranchRequest\x12\x30\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1e.pps_1_7.CreatePipelineRequest\"\x91\x02\n\x05Op1_8\x12)\n\x06object\x18\x02 \x01(\x0b\x32\x19.pfs_1_8.PutObjectRequest\x12&\n\x03tag\x18\x03 \x01(\x0b\x32\x19.pfs_1_8.TagObjectRequest\x12(\n\x04repo\x18\x04 \x01(\x0b\x32\x1a.pfs_1_8.CreateRepoRequest\x12+\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1b.pfs_1_8.BuildCommitRequest\x12,\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1c.pfs_1_8.CreateBranchRequest\x12\x30\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1e.pps_1_8.CreatePipelineRequest\"\x97\x03\n\x05Op1_9\x12)\n\x06object\x18\x02 \x01(\x0b\x32\x19.pfs_1_9.PutObjectRequest\x12\x33\n\rcreate_object\x18\t \x01(\x0b\x32\x1c.pfs_1_9.CreateObjectRequest\x12&\n\x03tag\x18\x03 \x01(\x0b\x32\x19.pfs_1_9.TagObjectRequest\x12\'\n\x05\x62lock\x18\n \x01(\x0b\x32\x18.pfs_1_9.PutBlockRequest\x12(\n\x04repo\x18\x04 \x01(\x0b\x32\x1a.pfs_1_9.CreateRepoRequest\x12+\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1b.pfs_1_9.BuildCommitRequest\x12,\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1c.pfs_1_9.CreateBranchRequest\x12\x30\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1e.pps_1_9.CreatePipelineRequest\x12&\n\x03job\x18\x08 \x01(\x0b\x32\x19.pps_1_9.CreateJobRequest\"\xa1\x03\n\x06Op1_10\x12*\n\x06object\x18\x02 \x01(\x0b\x32\x1a.pfs_1_10.PutObjectRequest\x12\x34\n\rcreate_object\x18\t \x01(\x0b\x32\x1d.pfs_1_10.CreateObjectRequest\x12\'\n\x03tag\x18\x03 \x01(\x0b\x32\x1a.pfs_1_10.TagObjectRequest\x12(\n\x05\x62lock\x18\n \x01(\x0b\x32\x19.pfs_1_10.PutBlockRequest\x12)\n\x04repo\x18\x04 \x01(\x0b\x32\x1b.pfs_1_10.CreateRepoRequest\x12,\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1c.pfs_1_10.BuildCommitRequest\x12-\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1d.pfs_1_10.CreateBranchRequest\x12\x31\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1f.pps_1_10.CreatePipelineRequest\x12\'\n\x03job\x18\x08 \x01(\x0b\x32\x1a.pps_1_10.CreateJobRequest\"\xba\x06\n\x06Op1_11\x12*\n\x06object\x18\x02 \x01(\x0b\x32\x1a.pfs_1_11.PutObjectRequest\x12\x34\n\rcreate_object\x18\t \x01(\x0b\x32\x1d.pfs_1_11.CreateObjectRequest\x12\'\n\x03tag\x18\x03 \x01(\x0b\x32\x1a.pfs_1_11.TagObjectRequest\x12(\n\x05\x62lock\x18\n \x01(\x0b\x32\x19.pfs_1_11.PutBlockRequest\x12)\n\x04repo\x18\x04 \x01(\x0b\x32\x1b.pfs_1_11.CreateRepoRequest\x12,\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1c.pfs_1_11.BuildCommitRequest\x12-\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1d.pfs_1_11.CreateBranchRequest\x12\x31\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1f.pps_1_11.CreatePipelineRequest\x12\'\n\x03job\x18\x08 \x01(\x0b\x32\x1a.pps_1_11.CreateJobRequest\x12)\n\x07set_acl\x18\x0b \x01(\x0b\x32\x18.auth_1_11.SetACLRequest\x12L\n\x18set_cluster_role_binding\x18\x0c \x01(\x0b\x32*.auth_1_11.ModifyClusterRoleBindingRequest\x12;\n\x0fset_auth_config\x18\r \x01(\x0b\x32\".auth_1_11.SetConfigurationRequest\x12\x31\n\ractivate_auth\x18\x0e \x01(\x0b\x32\x1a.auth_1_11.ActivateRequest\x12>\n\x12restore_auth_token\x18\x0f \x01(\x0b\x32\".auth_1_11.RestoreAuthTokenRequest\x12=\n\x13\x61\x63tivate_enterprise\x18\x10 \x01(\x0b\x32 .enterprise_1_11.ActivateRequest\x12/\n\x10\x63heck_auth_token\x18\x11 \x01(\x0b\x32\x15.admin.CheckAuthToken\"\xba\x06\n\x06Op1_12\x12*\n\x06object\x18\x02 \x01(\x0b\x32\x1a.pfs_1_12.PutObjectRequest\x12\x34\n\rcreate_object\x18\t \x01(\x0b\x32\x1d.pfs_1_12.CreateObjectRequest\x12\'\n\x03tag\x18\x03 \x01(\x0b\x32\x1a.pfs_1_12.TagObjectRequest\x12(\n\x05\x62lock\x18\n \x01(\x0b\x32\x19.pfs_1_12.PutBlockRequest\x12)\n\x04repo\x18\x04 \x01(\x0b\x32\x1b.pfs_1_12.CreateRepoRequest\x12,\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x1c.pfs_1_12.BuildCommitRequest\x12-\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x1d.pfs_1_12.CreateBranchRequest\x12\x31\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1f.pps_1_12.CreatePipelineRequest\x12\'\n\x03job\x18\x08 \x01(\x0b\x32\x1a.pps_1_12.CreateJobRequest\x12)\n\x07set_acl\x18\x0b \x01(\x0b\x32\x18.auth_1_12.SetACLRequest\x12L\n\x18set_cluster_role_binding\x18\x0c \x01(\x0b\x32*.auth_1_12.ModifyClusterRoleBindingRequest\x12;\n\x0fset_auth_config\x18\r \x01(\x0b\x32\".auth_1_12.SetConfigurationRequest\x12\x31\n\ractivate_auth\x18\x0e \x01(\x0b\x32\x1a.auth_1_12.ActivateRequest\x12>\n\x12restore_auth_token\x18\x0f \x01(\x0b\x32\".auth_1_12.RestoreAuthTokenRequest\x12=\n\x13\x61\x63tivate_enterprise\x18\x10 \x01(\x0b\x32 .enterprise_1_12.ActivateRequest\x12/\n\x10\x63heck_auth_token\x18\x11 \x01(\x0b\x32\x15.admin.CheckAuthToken\"\xef\x05\n\x06Op1_13\x12%\n\x06object\x18\x02 \x01(\x0b\x32\x15.pfs.PutObjectRequest\x12/\n\rcreate_object\x18\t \x01(\x0b\x32\x18.pfs.CreateObjectRequest\x12\"\n\x03tag\x18\x03 \x01(\x0b\x32\x15.pfs.TagObjectRequest\x12#\n\x05\x62lock\x18\n \x01(\x0b\x32\x14.pfs.PutBlockRequest\x12$\n\x04repo\x18\x04 \x01(\x0b\x32\x16.pfs.CreateRepoRequest\x12\'\n\x06\x63ommit\x18\x05 \x01(\x0b\x32\x17.pfs.BuildCommitRequest\x12(\n\x06\x62ranch\x18\x06 \x01(\x0b\x32\x18.pfs.CreateBranchRequest\x12,\n\x08pipeline\x18\x07 \x01(\x0b\x32\x1a.pps.CreatePipelineRequest\x12\"\n\x03job\x18\x08 \x01(\x0b\x32\x15.pps.CreateJobRequest\x12$\n\x07set_acl\x18\x0b \x01(\x0b\x32\x13.auth.SetACLRequest\x12G\n\x18set_cluster_role_binding\x18\x0c \x01(\x0b\x32%.auth.ModifyClusterRoleBindingRequest\x12\x36\n\x0fset_auth_config\x18\r \x01(\x0b\x32\x1d.auth.SetConfigurationRequest\x12,\n\ractivate_auth\x18\x0e \x01(\x0b\x32\x15.auth.ActivateRequest\x12\x39\n\x12restore_auth_token\x18\x0f \x01(\x0b\x32\x1d.auth.RestoreAuthTokenRequest\x12\x38\n\x13\x61\x63tivate_enterprise\x18\x10 \x01(\x0b\x32\x1b.enterprise.ActivateRequest\x12/\n\x10\x63heck_auth_token\x18\x11 \x01(\x0b\x32\x15.admin.CheckAuthToken\"\xd7\x01\n\x02Op\x12\x1b\n\x05op1_7\x18\x01 \x01(\x0b\x32\x0c.admin.Op1_7\x12\x1b\n\x05op1_8\x18\x02 \x01(\x0b\x32\x0c.admin.Op1_8\x12\x1b\n\x05op1_9\x18\x03 \x01(\x0b\x32\x0c.admin.Op1_9\x12\x1d\n\x06op1_10\x18\x04 \x01(\x0b\x32\r.admin.Op1_10\x12\x1d\n\x06op1_11\x18\x05 \x01(\x0b\x32\r.admin.Op1_11\x12\x1d\n\x06op1_12\x18\x06 \x01(\x0b\x32\r.admin.Op1_12\x12\x1d\n\x06op1_13\x18\x07 \x01(\x0b\x32\r.admin.Op1_13\"\x81\x01\n\x0e\x45xtractRequest\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x12\n\nno_objects\x18\x02 \x01(\x08\x12\x10\n\x08no_repos\x18\x03 \x01(\x08\x12\x14\n\x0cno_pipelines\x18\x04 \x01(\x08\x12\x15\n\rno_enterprise\x18\x05 \x01(\x08\x12\x0f\n\x07no_auth\x18\x06 \x01(\x08\"9\n\x16\x45xtractPipelineRequest\x12\x1f\n\x08pipeline\x18\x01 \x01(\x0b\x32\r.pps.Pipeline\"4\n\x0eRestoreRequest\x12\x15\n\x02op\x18\x01 \x01(\x0b\x32\t.admin.Op\x12\x0b\n\x03URL\x18\x02 \x01(\t\"0\n\x0b\x43lusterInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t2\xf3\x01\n\x03\x41PI\x12/\n\x07\x45xtract\x12\x15.admin.ExtractRequest\x1a\t.admin.Op\"\x00\x30\x01\x12=\n\x0f\x45xtractPipeline\x12\x1d.admin.ExtractPipelineRequest\x1a\t.admin.Op\"\x00\x12<\n\x07Restore\x12\x15.admin.RestoreRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12>\n\x0eInspectCluster\x12\x16.google.protobuf.Empty\x1a\x12.admin.ClusterInfo\"\x00\x42\x31Z/github.com/pachyderm/pachyderm/src/client/adminb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__7_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__8_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__9_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__10_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__11_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2.DESCRIPTOR,client_dot_admin_dot_v1__11_dot_enterprise_dot_enterprise__pb2.DESCRIPTOR,client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_admin_dot_v1__12_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2.DESCRIPTOR,client_dot_admin_dot_v1__12_dot_enterprise_dot_enterprise__pb2.DESCRIPTOR,client_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_pps_dot_pps__pb2.DESCRIPTOR,client_dot_auth_dot_auth__pb2.DESCRIPTOR,client_dot_enterprise_dot_enterprise__pb2.DESCRIPTOR,])




_CHECKAUTHTOKEN = _descriptor.Descriptor(
  name='CheckAuthToken',
  full_name='admin.CheckAuthToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=754,
)


_OP1_7 = _descriptor.Descriptor(
  name='Op1_7',
  full_name='admin.Op1_7',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_7.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_7.tag', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_7.repo', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_7.commit', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_7.branch', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_7.pipeline', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=1030,
)


_OP1_8 = _descriptor.Descriptor(
  name='Op1_8',
  full_name='admin.Op1_8',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_8.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_8.tag', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_8.repo', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_8.commit', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_8.branch', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_8.pipeline', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1033,
  serialized_end=1306,
)


_OP1_9 = _descriptor.Descriptor(
  name='Op1_9',
  full_name='admin.Op1_9',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_9.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_object', full_name='admin.Op1_9.create_object', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_9.tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='admin.Op1_9.block', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_9.repo', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_9.commit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_9.branch', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_9.pipeline', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='admin.Op1_9.job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1716,
)


_OP1_10 = _descriptor.Descriptor(
  name='Op1_10',
  full_name='admin.Op1_10',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_10.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_object', full_name='admin.Op1_10.create_object', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_10.tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='admin.Op1_10.block', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_10.repo', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_10.commit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_10.branch', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_10.pipeline', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='admin.Op1_10.job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=2136,
)


_OP1_11 = _descriptor.Descriptor(
  name='Op1_11',
  full_name='admin.Op1_11',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_11.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_object', full_name='admin.Op1_11.create_object', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_11.tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='admin.Op1_11.block', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_11.repo', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_11.commit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_11.branch', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_11.pipeline', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='admin.Op1_11.job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_acl', full_name='admin.Op1_11.set_acl', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_cluster_role_binding', full_name='admin.Op1_11.set_cluster_role_binding', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_auth_config', full_name='admin.Op1_11.set_auth_config', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_auth', full_name='admin.Op1_11.activate_auth', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_auth_token', full_name='admin.Op1_11.restore_auth_token', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_enterprise', full_name='admin.Op1_11.activate_enterprise', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_auth_token', full_name='admin.Op1_11.check_auth_token', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2965,
)


_OP1_12 = _descriptor.Descriptor(
  name='Op1_12',
  full_name='admin.Op1_12',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_12.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_object', full_name='admin.Op1_12.create_object', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_12.tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='admin.Op1_12.block', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_12.repo', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_12.commit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_12.branch', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_12.pipeline', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='admin.Op1_12.job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_acl', full_name='admin.Op1_12.set_acl', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_cluster_role_binding', full_name='admin.Op1_12.set_cluster_role_binding', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_auth_config', full_name='admin.Op1_12.set_auth_config', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_auth', full_name='admin.Op1_12.activate_auth', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_auth_token', full_name='admin.Op1_12.restore_auth_token', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_enterprise', full_name='admin.Op1_12.activate_enterprise', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_auth_token', full_name='admin.Op1_12.check_auth_token', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2968,
  serialized_end=3794,
)


_OP1_13 = _descriptor.Descriptor(
  name='Op1_13',
  full_name='admin.Op1_13',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='admin.Op1_13.object', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_object', full_name='admin.Op1_13.create_object', index=1,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='admin.Op1_13.tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='admin.Op1_13.block', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='admin.Op1_13.repo', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='admin.Op1_13.commit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='admin.Op1_13.branch', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.Op1_13.pipeline', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='admin.Op1_13.job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_acl', full_name='admin.Op1_13.set_acl', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_cluster_role_binding', full_name='admin.Op1_13.set_cluster_role_binding', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_auth_config', full_name='admin.Op1_13.set_auth_config', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_auth', full_name='admin.Op1_13.activate_auth', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_auth_token', full_name='admin.Op1_13.restore_auth_token', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activate_enterprise', full_name='admin.Op1_13.activate_enterprise', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_auth_token', full_name='admin.Op1_13.check_auth_token', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3797,
  serialized_end=4548,
)


_OP = _descriptor.Descriptor(
  name='Op',
  full_name='admin.Op',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op1_7', full_name='admin.Op.op1_7', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_8', full_name='admin.Op.op1_8', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_9', full_name='admin.Op.op1_9', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_10', full_name='admin.Op.op1_10', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_11', full_name='admin.Op.op1_11', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_12', full_name='admin.Op.op1_12', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op1_13', full_name='admin.Op.op1_13', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4551,
  serialized_end=4766,
)


_EXTRACTREQUEST = _descriptor.Descriptor(
  name='ExtractRequest',
  full_name='admin.ExtractRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='URL', full_name='admin.ExtractRequest.URL', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_objects', full_name='admin.ExtractRequest.no_objects', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_repos', full_name='admin.ExtractRequest.no_repos', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_pipelines', full_name='admin.ExtractRequest.no_pipelines', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_enterprise', full_name='admin.ExtractRequest.no_enterprise', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_auth', full_name='admin.ExtractRequest.no_auth', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4769,
  serialized_end=4898,
)


_EXTRACTPIPELINEREQUEST = _descriptor.Descriptor(
  name='ExtractPipelineRequest',
  full_name='admin.ExtractPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='admin.ExtractPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4900,
  serialized_end=4957,
)


_RESTOREREQUEST = _descriptor.Descriptor(
  name='RestoreRequest',
  full_name='admin.RestoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='admin.RestoreRequest.op', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='URL', full_name='admin.RestoreRequest.URL', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4959,
  serialized_end=5011,
)


_CLUSTERINFO = _descriptor.Descriptor(
  name='ClusterInfo',
  full_name='admin.ClusterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admin.ClusterInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='admin.ClusterInfo.deployment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5013,
  serialized_end=5061,
)

_OP1_7.fields_by_name['object'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_7.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_7.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_7.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_7.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_7.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__7_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_8.fields_by_name['object'].message_type = client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_8.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_8.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_8.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_8.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_8.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__8_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_9.fields_by_name['object'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_9.fields_by_name['create_object'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._CREATEOBJECTREQUEST
_OP1_9.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_9.fields_by_name['block'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._PUTBLOCKREQUEST
_OP1_9.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_9.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_9.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__9_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_9.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__9_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_9.fields_by_name['job'].message_type = client_dot_admin_dot_v1__9_dot_pps_dot_pps__pb2._CREATEJOBREQUEST
_OP1_10.fields_by_name['object'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_10.fields_by_name['create_object'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._CREATEOBJECTREQUEST
_OP1_10.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_10.fields_by_name['block'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._PUTBLOCKREQUEST
_OP1_10.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_10.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_10.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__10_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_10.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__10_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_10.fields_by_name['job'].message_type = client_dot_admin_dot_v1__10_dot_pps_dot_pps__pb2._CREATEJOBREQUEST
_OP1_11.fields_by_name['object'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_11.fields_by_name['create_object'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._CREATEOBJECTREQUEST
_OP1_11.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_11.fields_by_name['block'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._PUTBLOCKREQUEST
_OP1_11.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_11.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_11.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__11_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_11.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__11_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_11.fields_by_name['job'].message_type = client_dot_admin_dot_v1__11_dot_pps_dot_pps__pb2._CREATEJOBREQUEST
_OP1_11.fields_by_name['set_acl'].message_type = client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2._SETACLREQUEST
_OP1_11.fields_by_name['set_cluster_role_binding'].message_type = client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2._MODIFYCLUSTERROLEBINDINGREQUEST
_OP1_11.fields_by_name['set_auth_config'].message_type = client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2._SETCONFIGURATIONREQUEST
_OP1_11.fields_by_name['activate_auth'].message_type = client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2._ACTIVATEREQUEST
_OP1_11.fields_by_name['restore_auth_token'].message_type = client_dot_admin_dot_v1__11_dot_auth_dot_auth__pb2._RESTOREAUTHTOKENREQUEST
_OP1_11.fields_by_name['activate_enterprise'].message_type = client_dot_admin_dot_v1__11_dot_enterprise_dot_enterprise__pb2._ACTIVATEREQUEST
_OP1_11.fields_by_name['check_auth_token'].message_type = _CHECKAUTHTOKEN
_OP1_12.fields_by_name['object'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_12.fields_by_name['create_object'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._CREATEOBJECTREQUEST
_OP1_12.fields_by_name['tag'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_12.fields_by_name['block'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._PUTBLOCKREQUEST
_OP1_12.fields_by_name['repo'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_12.fields_by_name['commit'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_12.fields_by_name['branch'].message_type = client_dot_admin_dot_v1__12_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_12.fields_by_name['pipeline'].message_type = client_dot_admin_dot_v1__12_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_12.fields_by_name['job'].message_type = client_dot_admin_dot_v1__12_dot_pps_dot_pps__pb2._CREATEJOBREQUEST
_OP1_12.fields_by_name['set_acl'].message_type = client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2._SETACLREQUEST
_OP1_12.fields_by_name['set_cluster_role_binding'].message_type = client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2._MODIFYCLUSTERROLEBINDINGREQUEST
_OP1_12.fields_by_name['set_auth_config'].message_type = client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2._SETCONFIGURATIONREQUEST
_OP1_12.fields_by_name['activate_auth'].message_type = client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2._ACTIVATEREQUEST
_OP1_12.fields_by_name['restore_auth_token'].message_type = client_dot_admin_dot_v1__12_dot_auth_dot_auth__pb2._RESTOREAUTHTOKENREQUEST
_OP1_12.fields_by_name['activate_enterprise'].message_type = client_dot_admin_dot_v1__12_dot_enterprise_dot_enterprise__pb2._ACTIVATEREQUEST
_OP1_12.fields_by_name['check_auth_token'].message_type = _CHECKAUTHTOKEN
_OP1_13.fields_by_name['object'].message_type = client_dot_pfs_dot_pfs__pb2._PUTOBJECTREQUEST
_OP1_13.fields_by_name['create_object'].message_type = client_dot_pfs_dot_pfs__pb2._CREATEOBJECTREQUEST
_OP1_13.fields_by_name['tag'].message_type = client_dot_pfs_dot_pfs__pb2._TAGOBJECTREQUEST
_OP1_13.fields_by_name['block'].message_type = client_dot_pfs_dot_pfs__pb2._PUTBLOCKREQUEST
_OP1_13.fields_by_name['repo'].message_type = client_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_OP1_13.fields_by_name['commit'].message_type = client_dot_pfs_dot_pfs__pb2._BUILDCOMMITREQUEST
_OP1_13.fields_by_name['branch'].message_type = client_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_OP1_13.fields_by_name['pipeline'].message_type = client_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_OP1_13.fields_by_name['job'].message_type = client_dot_pps_dot_pps__pb2._CREATEJOBREQUEST
_OP1_13.fields_by_name['set_acl'].message_type = client_dot_auth_dot_auth__pb2._SETACLREQUEST
_OP1_13.fields_by_name['set_cluster_role_binding'].message_type = client_dot_auth_dot_auth__pb2._MODIFYCLUSTERROLEBINDINGREQUEST
_OP1_13.fields_by_name['set_auth_config'].message_type = client_dot_auth_dot_auth__pb2._SETCONFIGURATIONREQUEST
_OP1_13.fields_by_name['activate_auth'].message_type = client_dot_auth_dot_auth__pb2._ACTIVATEREQUEST
_OP1_13.fields_by_name['restore_auth_token'].message_type = client_dot_auth_dot_auth__pb2._RESTOREAUTHTOKENREQUEST
_OP1_13.fields_by_name['activate_enterprise'].message_type = client_dot_enterprise_dot_enterprise__pb2._ACTIVATEREQUEST
_OP1_13.fields_by_name['check_auth_token'].message_type = _CHECKAUTHTOKEN
_OP.fields_by_name['op1_7'].message_type = _OP1_7
_OP.fields_by_name['op1_8'].message_type = _OP1_8
_OP.fields_by_name['op1_9'].message_type = _OP1_9
_OP.fields_by_name['op1_10'].message_type = _OP1_10
_OP.fields_by_name['op1_11'].message_type = _OP1_11
_OP.fields_by_name['op1_12'].message_type = _OP1_12
_OP.fields_by_name['op1_13'].message_type = _OP1_13
_EXTRACTPIPELINEREQUEST.fields_by_name['pipeline'].message_type = client_dot_pps_dot_pps__pb2._PIPELINE
_RESTOREREQUEST.fields_by_name['op'].message_type = _OP
DESCRIPTOR.message_types_by_name['CheckAuthToken'] = _CHECKAUTHTOKEN
DESCRIPTOR.message_types_by_name['Op1_7'] = _OP1_7
DESCRIPTOR.message_types_by_name['Op1_8'] = _OP1_8
DESCRIPTOR.message_types_by_name['Op1_9'] = _OP1_9
DESCRIPTOR.message_types_by_name['Op1_10'] = _OP1_10
DESCRIPTOR.message_types_by_name['Op1_11'] = _OP1_11
DESCRIPTOR.message_types_by_name['Op1_12'] = _OP1_12
DESCRIPTOR.message_types_by_name['Op1_13'] = _OP1_13
DESCRIPTOR.message_types_by_name['Op'] = _OP
DESCRIPTOR.message_types_by_name['ExtractRequest'] = _EXTRACTREQUEST
DESCRIPTOR.message_types_by_name['ExtractPipelineRequest'] = _EXTRACTPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['RestoreRequest'] = _RESTOREREQUEST
DESCRIPTOR.message_types_by_name['ClusterInfo'] = _CLUSTERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckAuthToken = _reflection.GeneratedProtocolMessageType('CheckAuthToken', (_message.Message,), {
  'DESCRIPTOR' : _CHECKAUTHTOKEN,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.CheckAuthToken)
  })
_sym_db.RegisterMessage(CheckAuthToken)

Op1_7 = _reflection.GeneratedProtocolMessageType('Op1_7', (_message.Message,), {
  'DESCRIPTOR' : _OP1_7,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_7)
  })
_sym_db.RegisterMessage(Op1_7)

Op1_8 = _reflection.GeneratedProtocolMessageType('Op1_8', (_message.Message,), {
  'DESCRIPTOR' : _OP1_8,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_8)
  })
_sym_db.RegisterMessage(Op1_8)

Op1_9 = _reflection.GeneratedProtocolMessageType('Op1_9', (_message.Message,), {
  'DESCRIPTOR' : _OP1_9,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_9)
  })
_sym_db.RegisterMessage(Op1_9)

Op1_10 = _reflection.GeneratedProtocolMessageType('Op1_10', (_message.Message,), {
  'DESCRIPTOR' : _OP1_10,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_10)
  })
_sym_db.RegisterMessage(Op1_10)

Op1_11 = _reflection.GeneratedProtocolMessageType('Op1_11', (_message.Message,), {
  'DESCRIPTOR' : _OP1_11,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_11)
  })
_sym_db.RegisterMessage(Op1_11)

Op1_12 = _reflection.GeneratedProtocolMessageType('Op1_12', (_message.Message,), {
  'DESCRIPTOR' : _OP1_12,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_12)
  })
_sym_db.RegisterMessage(Op1_12)

Op1_13 = _reflection.GeneratedProtocolMessageType('Op1_13', (_message.Message,), {
  'DESCRIPTOR' : _OP1_13,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op1_13)
  })
_sym_db.RegisterMessage(Op1_13)

Op = _reflection.GeneratedProtocolMessageType('Op', (_message.Message,), {
  'DESCRIPTOR' : _OP,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.Op)
  })
_sym_db.RegisterMessage(Op)

ExtractRequest = _reflection.GeneratedProtocolMessageType('ExtractRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTREQUEST,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.ExtractRequest)
  })
_sym_db.RegisterMessage(ExtractRequest)

ExtractPipelineRequest = _reflection.GeneratedProtocolMessageType('ExtractPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACTPIPELINEREQUEST,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.ExtractPipelineRequest)
  })
_sym_db.RegisterMessage(ExtractPipelineRequest)

RestoreRequest = _reflection.GeneratedProtocolMessageType('RestoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTOREREQUEST,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.RestoreRequest)
  })
_sym_db.RegisterMessage(RestoreRequest)

ClusterInfo = _reflection.GeneratedProtocolMessageType('ClusterInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERINFO,
  '__module__' : 'client.admin.admin_pb2'
  # @@protoc_insertion_point(class_scope:admin.ClusterInfo)
  })
_sym_db.RegisterMessage(ClusterInfo)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='admin.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5064,
  serialized_end=5307,
  methods=[
  _descriptor.MethodDescriptor(
    name='Extract',
    full_name='admin.API.Extract',
    index=0,
    containing_service=None,
    input_type=_EXTRACTREQUEST,
    output_type=_OP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtractPipeline',
    full_name='admin.API.ExtractPipeline',
    index=1,
    containing_service=None,
    input_type=_EXTRACTPIPELINEREQUEST,
    output_type=_OP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Restore',
    full_name='admin.API.Restore',
    index=2,
    containing_service=None,
    input_type=_RESTOREREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectCluster',
    full_name='admin.API.InspectCluster',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CLUSTERINFO,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



from python_pachyderm.service import Service


class EnterpriseMixin:
    def activate_enterprise(self, activation_code, expires=None):
        """
        Activates enterprise. Returns a `TokenInfo` object.

        Params:

        * `activation_code`: A string specifying a Pachyderm enterprise
        activation code. New users can obtain trial activation codes.
        * `expires`: An optional `Timestamp` object indicating when this
        activation code will expire. This should not generally be set (it's
        primarily used for testing), and is only applied if it's earlier than
        the signed expiration time in `activation_code`.
        """
        return self._req(
            Service.ENTERPRISE,
            "Activate",
            activation_code=activation_code,
            expires=expires,
        ).info

    def get_enterprise_state(self):
        """
        Gets the current enterprise state of the cluster. Returns a
        `GetEnterpriseResponse` object.
        """
        return self._req(Service.ENTERPRISE, "GetState")

    def deactivate_enterprise(self):
        """Deactivates enterprise."""
        return self._req(Service.ENTERPRISE, "Deactivate")

    def get_activation_code(self):
        """
        Returns the enterprise code used to activate Pachdyerm Enterprise in
        this cluster.
        """
        return self._req(Service.ENTERPRISE, "GetActivationCode")
